@@ -76,7 +76,7 @@ import html2text
 
 
 # version
-__version__         = '0.6.0'  # was v1.2.0 before deployment to PyPi
+__version__         = '0.7.0'
 
 # BUILTIN ICONS
 ICON_EXCLAMATION    = 'yes'
@@ -93,11 +93,8 @@ ICON_PRIO2          = 'full-2'
 class Mindmap(object):
 
     """
-    Freeplane interfacing class
-
-    access Freeplane mindmap file and do various search, read and write
-    operations to retrieve or modify text passages, design and structures
-    within the mindmap.
+    representation of Freeplane mindmap file as a container for nodes. access
+    styles and other general features from here.
 
     """
 
@@ -452,21 +449,28 @@ class Mindmap(object):
 
     @classmethod
     def get_num_of_maps(cls):
+        """
+        return the number of maps already created within the current session
+
+        :returns: integer
+        """
+
         return cls._num_of_maps
 
     @classmethod
     def create_node_id(cls, mindmap=None):
+        """
+        create a valid node id. this node id is incremented automatically,
+        whenever a new XML node is created. even if it is discarded later.
+        the node id, here consists of three parts:
 
-        # create a valid node id. this node id is incremented automatically,
-        # whenever a new XML node is created. even if it is discarded later.
-        # the node id, here consists of three parts:
-        #
-        #   1. the id token "ID_" which is used for all nodes directly created
-        #      within freeplane editor
-        #
-        #   2. and kind of session seed which is the current date
-        #
-        #   3. and a standard 4-digit integer value constantly incremented
+            1. the id token "ID_" which is used for all nodes directly created
+               within freeplane editor
+        
+            2. and kind of session seed which is the current date
+        
+            3. and a standard 4-digit integer value constantly incremented
+        """
 
         # increment future part of node id
         cls._global_node_id_incr += 1
@@ -972,7 +976,7 @@ class Branch(object):
 # define a structure to externally provide named arrow link styles. these can
 # be set an retrieved when creating arrow links.
 
-class ArrayStyles(object):
+class ArrowStyles(object):
 
     def __init__(self):
 
@@ -995,6 +999,10 @@ class ArrayStyles(object):
 # NODE
 
 class Node(object):
+    """
+    representation of Freeplane node elements found within a mindmap. all the
+    node-related features can be accessed from here.
+    """
 
     def __init__(self, node, mindmap):
 
@@ -1138,6 +1146,120 @@ class Node(object):
 
 
 
+        #
+        # set creation and modification dates
+        #
+
+        update_date_attribute_in_node(
+                node=self._node,
+                date=modified,
+                key="MODIFIED",
+                )
+
+        return True
+
+
+    @property
+    def imagepath(self):
+
+        # check if node holds no in-line image
+        if self._node.find('hook') is None:
+            # print(f'[ WARNING: the node "{self.id}" does not contain an in-line image. ]')
+            return None
+
+        # get hook node
+        hook = self._node.find('hook')
+
+        # get uri attribute
+        uri = hook.attrib.get("URI", "")
+
+        # sanitize uri
+        uri = uri.replace("file://", "")
+
+        # somehow, freeplane currently stores paths in the image hook with
+        # THREE slashes after the protocol token "file". for Linux, this makes
+        # sense when dealing with absolute file paths (all starting with
+        # another "/"). but for Windows this doesn't make sense as there
+        # remains an additional "/" in front of the drive specification "C:" of
+        # absolute path definitions. this is to be corrected, here, as long it
+        # is not corrected within Freeplane.
+
+        # check for leading slash in front of drive token
+        _match = re.search(r'^(/[A-z]:/)', uri)
+        if _match:
+            # remove leading slash
+            uri = uri[1:]
+
+        return uri
+
+    @property
+    def imagesize(self):
+
+        # check if node holds no in-line image
+        if self._node.find('hook') is None:
+            print(f'[ WARNING: the node "{self._node.id}" does not contain an in-line image. ]')
+            return None
+
+        # get hook node
+        hook = self._node.find('hook')
+
+        # get uri attribute
+        size = hook.attrib.get("SIZE", "")
+
+        return size
+
+    def set_image(self,
+            link="",
+            size="1",
+            modified='',
+            ):
+
+
+
+
+        #
+        # prepare path string
+        #
+
+        # check for Windows-style absolute path
+        _match = re.search(r'^([A-z]:/)', link)
+
+        # check for absolute linux path
+        if link[0] == "/":
+            link = "file://" + link
+        # check for absolute windows path
+        elif _match:
+            link = "file:///" + link
+        # should be relative path
+        elif link[0] == ".":
+            pass
+        else:
+            link = "./" + link
+
+        # localize XML hook element below node
+        hook = self._node.find('hook')
+        if hook is None:
+
+            # create hook element
+            hook = ET.Element(
+                    "hook",
+                    URI=link,
+                    SIZE=str(link),
+                    NAME='ExternalObject',
+                    )
+
+            # add hook to node's children
+            self._node.append(hook)
+
+        else:
+
+            # just override attributes
+            hook.set("URI", link)
+            hook.set("SIZE", size)
+
+
+
+
         #
         # set creation and modification dates
         #
@@ -2489,6 +2611,18 @@ def reduce_node_list(
                     _lstNodes.append(_node)
         lstXmlNodes = _lstNodes
 
+    # check for LINK within a node's LINK TEXT
+    if link:
+        _lstNodes = []
+        for _node in lstXmlNodes:
+            if exact:
+                if link == _node.attrib.get("LINK", ""):
+                    _lstNodes.append(_node)
+            else:
+                if link.lower() in _node.attrib.get("LINK", "").lower():
+                    _lstNodes.append(_node)
+        lstXmlNodes = _lstNodes
+
     # check for BUILTIN ICON at node
     if icon:
         _lstNodes = []
